package com.qmth.sop.business.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.boot.api.exception.ApiException;
import com.qmth.sop.business.bean.result.TBQualityProblemApplyResult;
import com.qmth.sop.business.entity.SysUser;
import com.qmth.sop.business.entity.TBQualityProblemApply;
import com.qmth.sop.business.mapper.TBQualityProblemApplyMapper;
import com.qmth.sop.business.service.TBQualityProblemApplyService;
import com.qmth.sop.common.enums.*;
import com.qmth.sop.common.util.ResultUtil;
import com.qmth.sop.common.util.ServletUtil;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Map;
import java.util.Objects;

/**
 * 质量问题反馈表 服务实现.
 *
 * @author: shudonghui
 * @date: 2023-08-14 14:00:01
 * @version: 1.0
 * @email: shudonghui@qmth.com.cn
 * @Company: www.qmth.com.cn
 */
@Service
public class TBQualityProblemApplyServiceImpl extends ServiceImpl<TBQualityProblemApplyMapper, TBQualityProblemApply> implements TBQualityProblemApplyService {


    /**
     * 查询列表
     *
     * @param iPage
     * @return
     */
//		@Override
//		public IPage<TBQualityProblemApply> query(IPage<Map> iPage,String query) {
//				return this.baseMapper.query(iPage,query);
//		}
    @Override
    public IPage<TBQualityProblemApplyResult> query(IPage<Map> iPage, Long serviceId, Long userId, QualityProblemTypeEnum type, QualityProblemReasonEnum reason, InfluenceDegreeEnum degree, String custom, String problemNo, Long startTime, Long endTime) {
        return this.baseMapper.query(iPage, serviceId,userId,Objects.nonNull(type)?type.name():null,Objects.nonNull(reason)?reason.name():null,Objects.nonNull(degree)?degree.name():null,custom,problemNo,startTime,endTime);
    }

    /**
     * 新增修改质量问题反馈表
     *
     * @param tBQualityProblemApply
     */
    @Override
    @Transactional
    public Boolean saveTBQualityProblemApply(TBQualityProblemApply tBQualityProblemApply) {
        try {
            SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
            if (Objects.isNull(tBQualityProblemApply.getId())) {// 新增
                tBQualityProblemApply.setCreateId(1l);
            } else { // 修改
            }
            return saveOrUpdate(tBQualityProblemApply);
        } catch (Exception e) {
            if (e instanceof DuplicateKeyException) {
                String errorColumn = e.getCause().toString();
                String columnStr = errorColumn.substring(errorColumn.lastIndexOf("key") + 3, errorColumn.length()).replaceAll("'", "");
                throw ExceptionResultEnum.SQL_ERROR.exception("[" + FieldUniqueEnum.convertToTitle(columnStr) + "]数据不允许重复插入");
            } else if (e instanceof ApiException) {
                ResultUtil.error((ApiException) e, e.getMessage());
            } else {
                ResultUtil.error(e.getMessage());
            }
        }
        return null;

    }

    /**
     * 删除质量问题反馈表
     *
     * @param ids
     */
    @Override
    @Transactional
    public Boolean delete(long[] ids) {
        for (long id : ids) {
            this.removeById(id);
        }
        return true;
    }

}